clustergrammer_widget2
===============================

Interactive heatmap built using WebGL

Installation
------------

To install use pip:

    $ pip install clustergrammer_widget2
    $ jupyter nbextension enable --py --sys-prefix clustergrammer_widget2


For a development installation (requires npm),

    $ git clone https://github.com/maayanlab/clustergrammer_widget2.git
    $ cd clustergrammer_widget2
    $ pip install -e .
    $ jupyter nbextension install --py --symlink --sys-prefix clustergrammer_widget2
    $ jupyter nbextension enable --py --sys-prefix clustergrammer_widget2
